@@ -24,7 +24,7 @@ from singer import utils
 from singer.catalog import Catalog, CatalogEntry
 from singer.schema import Schema
 
-from macrometa_source_snowflake.sync_strategies.sample_data import fetch_samples
+from macrometa_source_snowflake.sync_strategies.sample_data import fetch_samples, modify_reserved_keys
 import macrometa_source_snowflake.sync_strategies.common as common
 import macrometa_source_snowflake.sync_strategies.full_table as full_table
 import macrometa_source_snowflake.sync_strategies.incremental as incremental
@@ -564,22 +564,37 @@ class SnowflakeSourceConnector(C8Connector):
         config = self.get_config(integration)
         try:
             snowflake_conn = SnowflakeConnection(config)
-            catalog = do_discover(snowflake_conn, config)
+            catalog = discover_catalog(snowflake_conn, config)
             results = []
+            
             for stream in catalog.streams:
                 s_attribs = []
                 s_schema = stream.schema
+                LOGGER.info('DEBUG SAMPLE 3: %s', s_schema)
                 data = fetch_samples(config, stream)[:10]
+                LOGGER.info('DEBUG SAMPLE 4: %s', data)
+                # Appending _ to keys for preserving values of reserved keys in source data
+                reserved_keys = ['_key', '_id', '_rev']
+                metadata_obj = stream.metadata[0]
+                if metadata_obj.metadata.get('table-key-properties'):
+                    key_properties = metadata_obj.metadata.get('table-key-properties')
+                    if key_properties[0] == '_key':
+                            reserved_keys.remove('_key')
+                properties = s_schema.properties
+                modified_properties = modify_reserved_keys(properties, reserved_keys)
+                s_schema.properties = modified_properties
                 for k, v in s_schema.properties.items():
-                    t = v['type'][-1]
+                    t = v.type[-1]
                     s_attribs.append(SchemaAttribute(
                         k, self.get_attribute_type(t)))
+                LOGGER.info('DEBUG SAMPLE 6: %s', str(s_attribs))
                 schema = C8Schema(stream.stream, s_attribs)
                 results.append(Sample(
                     schema=schema,
                     data=data)
                 )
         except Exception as e:
+            LOGGER.info('Exception raised: %s', e)
             raise e
         return results
 
@@ -589,15 +604,29 @@ class SnowflakeSourceConnector(C8Connector):
         config = self.get_config(integration)
         try:
             snowflake_conn = SnowflakeConnection(config)
-            catalog = do_discover(snowflake_conn, config)
+            LOGGER.info('DEBUG 1: %s', config)
+            catalog = discover_catalog(snowflake_conn, config)
+            LOGGER.info('DEBUG 2: %s', catalog)
             results = []
             for stream in catalog.streams:
                 s_attribs = []
                 s_schema = stream.schema
+                LOGGER.info('DEBUG 3: %s', s_schema)
+                # Appending _ to keys for preserving values of reserved keys in source data
+                reserved_keys = ['_key', '_id', '_rev']
+                metadata_obj = stream.metadata[0]
+                if metadata_obj.metadata.get('table-key-properties'):
+                    key_properties = metadata_obj.metadata.get('table-key-properties')
+                    if key_properties[0] == '_key':
+                            reserved_keys.remove('_key')
+                properties = s_schema.properties
+                modified_properties = modify_reserved_keys(properties, reserved_keys)
+                s_schema.properties = modified_properties
                 for k, v in s_schema.properties.items():
-                    t = v['type'][-1]
+                    t = v.type[-1]
                     s_attribs.append(SchemaAttribute(
                         k, self.get_attribute_type(t)))
+                LOGGER.info('DEBUG 4: %s', s_attribs)
                 results.append(C8Schema(stream.stream, s_attribs))
         except Exception as e:
             raise e
